# Table flat-json

Use Plugin: [bootstrap-table-flat-json](https://github.com/djhvscf/bootstrap-table-flat-json)

## Usage

```html
<script src="extensions/flat-json/bootstrap-table-flat-json.js"></script>
```

## Options

### flat

* type: Boolean
* description: Set true to flat the JSON object.
* default: `false`

### flatSeparator

* type: String
* description: Set the default separator between object levels.
* default: `.`